import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformRESTFloatToSDKFloat } from '@wix/sdk-runtime/transformations/float';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixAnalyticsNgDataV2PubSiteAnalyticsDataServiceUrl(opts) {
    const domainToMappings = {
        'bo._base_domain_': [
            {
                srcPath: '/analytics-ng-bo/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng-bo/v2',
                destPath: '/v2',
            },
        ],
        'wixbo.ai': [
            {
                srcPath: '/analytics-ng-bo/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng-bo/v2',
                destPath: '/v2',
            },
        ],
        'wix-bo.com': [
            {
                srcPath: '/analytics-ng-bo/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng-bo/v2',
                destPath: '/v2',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/analytics-ng/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng/report',
                destPath: '/report',
            },
            {
                srcPath: '/analytics-ng/assets',
                destPath: '/assets',
            },
            {
                srcPath: '/analytics-ng/hook',
                destPath: '/hook',
            },
            {
                srcPath: '/analytics-ng/debug-permissions',
                destPath: '/_debug_/permissions',
            },
            {
                srcPath: '/analytics-ng/debug-digest-email',
                destPath: '/debug-digest-email',
            },
            {
                srcPath: '/analytics-ng/utils',
                destPath: '/utils',
            },
            {
                srcPath: '/analytics-ng/v1',
                destPath: '/v1',
            },
            {
                srcPath: '/analytics-ng/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/analytics-ng/debug-partners-digest-email',
                destPath: '/debug-partners-digest-email',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/analytics-ng/api',
                destPath: '/api',
            },
            {
                srcPath: '/analytics-ng/assets',
                destPath: '/assets',
            },
            {
                srcPath: '/analytics-ng/report',
                destPath: '/report',
            },
            {
                srcPath: '/analytics-ng/hook',
                destPath: '/hook',
            },
            {
                srcPath: '/analytics-ng/utils',
                destPath: '/utils',
            },
            {
                srcPath: '/analytics-ng/debug-digest-email',
                destPath: '/debug-digest-email',
            },
            {
                srcPath: '/analytics-ng/subscriptions/off',
                destPath: '/subscriptions/off',
            },
            {
                srcPath: '/analytics-ng/subscriptions/debug/get-unsubscribe-token',
                destPath: '/subscriptions/debug/get-unsubscribe-token',
            },
            {
                srcPath: '/analytics-ng/v1',
                destPath: '/v1',
            },
            {
                srcPath: '/analytics-ng/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/analytics-ng/debug-partners-digest-email',
                destPath: '/debug-partners-digest-email',
            },
            {
                srcPath: '/analytics-ng/v3',
                destPath: '/v3',
            },
            {
                srcPath: '/analytics-ng/v5',
                destPath: '/v5',
            },
            {
                srcPath: '/analytics-ng/v4',
                destPath: '/v4',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/analytics-ng-server',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/analytics/v1/sessions/',
                destPath: '/v1/sessions/',
            },
            {
                srcPath: '/analytics/v2/site-analytics/',
                destPath: '/v2/site-analytics/',
            },
            {
                srcPath: '/analytics/v2/site-analytics',
                destPath: '/v2/site-analytics',
            },
            {
                srcPath: '/analytics/v1/sessions',
                destPath: '/v1/sessions',
            },
            {
                srcPath: '/analytics-ng/v1/sessions',
                destPath: '/v1/sessions',
            },
            {
                srcPath: '/analytics-ng/v2/site-analytics/data',
                destPath: '/v2/site-analytics/data',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/analytics-ng/v2/site-analytics/data',
                destPath: '/v2/site-analytics/data',
            },
            {
                srcPath: '/analytics-ng/v1/sessions',
                destPath: '/v1/sessions',
            },
        ],
        _: [
            {
                srcPath: '/analytics-ng/v2/site-analytics/data',
                destPath: '/v2/site-analytics/data',
            },
            {
                srcPath: '/analytics-ng/v1/sessions',
                destPath: '/v1/sessions',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_analytics-data_analytics-data';
/** Retrieves analytics data, given the specified filtering. */
export function getAnalyticsData(payload) {
    function __getAnalyticsData({ host }) {
        const metadata = {
            entityFqdn: 'wix.analytics_ng.v2.data',
            method: 'GET',
            methodFqn: 'wix.analytics_ng.data.v2.pub.SiteAnalyticsDataService.GetAnalyticsData',
            packageName: PACKAGE_NAME,
            url: resolveWixAnalyticsNgDataV2PubSiteAnalyticsDataServiceUrl({
                protoPath: '/v2/site-analytics/data',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTFloatToSDKFloat,
                    paths: [{ path: 'data.total' }, { path: 'data.values.value' }],
                },
            ]),
        };
        return metadata;
    }
    return __getAnalyticsData;
}
//# sourceMappingURL=analytics-ng-v2-data-analytics-data.http.js.map